# Python client and module for BGP Ranking

THis project will make querying BGP Ranking easier.

## Installation

```bash
pip install pybgpranking
```

## Usage

### Command line

You can use the `bgpranking` command to query the instance:

```bash
```

### Library

See [API Reference]()
